@@ -1,13 +1,16 @@
+import sys
+
 from pytoolconfig.sources import IniConfig, PyProject, SetupConfig
 
 
 def test_base_pyproject(cwd):
     pyproject = PyProject(cwd, "pytoolconfig", [])
     assert pyproject.parse()["formatter"] == "black"
-    assert pyproject._min_py_version == (3, 7)
     universal = pyproject.universalconfig()
     assert universal.min_py_version == (3, 7)
+    assert universal.max_py_version == (sys.version_info.major, sys.version_info.minor)
     assert universal.formatter == "black"
+    assert "sphinx" in [dep.name for dep in universal.optional_dependencies["doc"]]
 
 
 def test_base_ini(cwd):
@@ -18,6 +21,3 @@ def test_base_ini(cwd):
 def test_setup_cfg(cwd):
     setup_cfg = SetupConfig(cwd, "pytoolconfig")
     assert setup_cfg.parse()
-    assert setup_cfg._min_py_version == (3, 8)
-    universal = setup_cfg.universalconfig()
-    assert universal.min_py_version == (3, 8)
